@@ -6,7 +6,7 @@
 #' @return A `summary.tna` object (invisibly) containing the TNA model network
 #' metrics and values.
 #' @examples
-#' model <- tna(engagement)
+#' model <- tna(group_regulation)
 #' print(summary(model))
 #'
 print.summary.tna <- function(x, ...) {
@@ -21,7 +21,7 @@ print.summary.tna <- function(x, ...) {
 #' @return A `summary.tna_bootstrap` object (invisibly) containing the weight,
 #' p-value and confidence interval of each edge.
 #' @examples
-#' model <- tna(engagement)
+#' model <- tna(group_regulation)
 #' # Small number of iterations for CRAN
 #' boot <- bootstrap(model, iter = 10)
 #' print(summary(boot))
@@ -41,7 +41,7 @@ print.summary.tna_bootstrap <- function(x, ...) {
 #' @param ... Ignored.
 #' @return The `tna` object passed as argument `x` (invisibly).
 #' @examples
-#' model <- tna(engagement)
+#' model <- tna(group_regulation)
 #' print(model)
 #'
 print.tna <- function(x, digits = getOption("digits"), generic = FALSE, ...) {
@@ -52,13 +52,16 @@ print.tna <- function(x, digits = getOption("digits"), generic = FALSE, ...) {
     NextMethod(generic = "print", object = x, ...)
     return()
   }
-  check_nonnegative(digits)
+  check_values(digits)
   type <- attr(x, "type")
   mat_type <- switch(type,
-    `relative` = "Transition Probability",
-    `frequency` = "Transition Frequency",
-    `co-occurrence` = "Co-occurrence",
-    `betweenness` = "Edge Betweenness"
+                     `relative` = "Transition Probability",
+                     `frequency` = "Transition Frequency",
+                     `co-occurrence` = "Co-occurrence",
+                     `n-gram` = "N-gram Transition",
+                     `gap` = "Gap-allowed Transition",
+                     `window` = "Sliding Window Transition",
+                     `betweenness` = "Edge Betweenness"
   )
   cat("State Labels\n\n")
   cat(paste(x$labels, collapse = ", "), "\n")
@@ -84,7 +87,7 @@ print.tna <- function(x, digits = getOption("digits"), generic = FALSE, ...) {
 #' @param ... Ignored.
 #' @return `x` (invisibly).
 #' @examples
-#' model <- tna(engagement)
+#' model <- tna(group_regulation)
 #' # Small number of iterations for CRAN
 #' boot <- bootstrap(model, iter = 10)
 #' print(boot)
@@ -93,7 +96,7 @@ print.tna_bootstrap <- function(x, digits = getOption("digits"),
                                 type = "both", ...) {
   check_missing(x)
   check_class(x, "tna_bootstrap")
-  check_nonnegative(digits)
+  check_values(digits)
   type <- check_match(type, c("both", "sig", "nonsig"))
   sig <- x$summary$sig
   edges <- x$summary |>
@@ -112,7 +115,6 @@ print.tna_bootstrap <- function(x, digits = getOption("digits"),
   invisible(x)
 }
 
-
 #' Print Centrality Measures
 #'
 #' @export
@@ -120,7 +122,7 @@ print.tna_bootstrap <- function(x, digits = getOption("digits"),
 #' @param ... Ignored.
 #' @return `x` (invisibly).
 #' @examples
-#' model <- tna(engagement)
+#' model <- tna(group_regulation)
 #' cm <- centralities(model)
 #' print(cm)
 #'
@@ -135,20 +137,48 @@ print.tna_centralities <- function(x, ...) {
 #' @param ... Ignored.
 #' @return `x` (invisibly).
 #' @examples
-#' model <- tna(engagement)
+#' model <- tna(group_regulation)
 #' comm <- communities(model)
 #' print(comm)
 #'
 print.tna_communities <- function(x, ...) {
   check_missing(x)
   check_class(x, "tna_communities")
-  cat("Number of communities found by each algorithm:\n")
+  cat("Number of communities found by each algorithm:\n\n")
   print(x$counts)
-  cat("\nCommunity assignments:\n")
+  cat("\nCommunity assignments:\n\n")
   print(x$assignments)
   invisible(x)
 }
 
+#' Print Comparison Results
+#'
+#' @export
+#' @param x A `tna_comparison` object.
+#' @param ... Additional arguments passed to the tibble `print` method.
+#' @return `x` (invisibly).
+#' @examples
+#' model_x <- tna(group_regulation[1:200, ])
+#' model_y <- tna(group_regulation[1001:1200, ])
+#' comp <- compare(model_x, model_y)
+#' print(comp)
+#'
+print.tna_comparison <- function(x, ...) {
+  check_missing(x)
+  check_class(x, "tna_comparison")
+  cat("Edge difference metrics\n")
+  print(x$edge_metrics, ...)
+  cat("\nSummary metrics of differences\n")
+  print(x$summary_metrics, ...)
+  cat("\nNetwork metrics\n")
+  print(x$network_metrics, ...)
+  cat("\nCentrality differences\n")
+  print(x$centrality_differences, ...)
+  cat("\nCentrality correlations\n")
+  print(x$centrality_correlations, ...)
+  invisible(x)
+}
+
 #' Print Found Cliques of a TNA Network
 #'
 #' @export
@@ -162,7 +192,7 @@ print.tna_communities <- function(x, ...) {
 #' @param ... Ignored.
 #' @return `x` (invisibly).
 #' @examples
-#' model <- tna(engagement)
+#' model <- tna(group_regulation)
 #' cliq <- cliques(model, size = 2)
 #' print(cliq)
 #'
@@ -176,9 +206,9 @@ print.tna_cliques <- function(x, n = 6, first = 1,
     cat("No ", attr(x, "size"), "-cliques were found in the network.", sep = "")
     return(invisible(x))
   }
-  check_positive(n)
-  check_positive(first)
-  check_nonnegative(digits)
+  check_values(n, strict = TRUE)
+  check_values(first, strict = TRUE)
+  check_values(digits)
   n <- min(n, n_cliques)
   threshold <- attr(x, "threshold")
   cluster <- attr(x, "cluster")
@@ -200,6 +230,35 @@ print.tna_cliques <- function(x, n = 6, first = 1,
   invisible(x)
 }
 
+#' Print a TNA data object
+#'
+#' @export
+#' @param x A `tna_data` object.
+#' @param data A `character` string that defines the data to be printed
+#' tibble. Accepts either `"sequence"` (default) for wide format sequence data,
+#' `"meta"`, for the wide format metadata, or `"long"` for the long format
+#' data.
+#' @param ... Arguments passed to the tibble `print` method.
+#' @return `x` (invisibly).
+#' @examples
+#' data_single_session <- tibble::tibble(
+#'   action = c(
+#'     "view", "click", "add_cart", "view", "checkout", "view", "click", "share"
+#'    )
+#' )
+#' results_single <- prepare_data(data_single_session, action = "action")
+#' print(results_single, which = "sequence")
+#' print(results_single, which = "meta")
+#' print(results_single, which = "long")
+#'
+print.tna_data <- function(x, data = "sequence", ...) {
+  check_missing(x)
+  check_class(x, "tna_data")
+  data <- check_match(data, c("sequence", "meta", "long"))
+  idx <- paste0(data, "_data")
+  print(x[[idx]])
+}
+
 #' Print Centrality Stability Results
 #'
 #' @export
@@ -207,7 +266,7 @@ print.tna_cliques <- function(x, n = 6, first = 1,
 #' @param ... Ignored.
 #' @return `x` (invisibly).
 #' @examples
-#' model <- tna(engagement)
+#' model <- tna(group_regulation)
 #' # Small number of iterations and drop proportions for CRAN
 #' cs <- estimate_cs(
 #'   model,
@@ -268,7 +327,14 @@ print.tna_permutation <- function(x, ...) {
 print.group_tna <- function(x, ...) {
   check_missing(x)
   check_class(x, "group_tna")
-  lapply(x, \(i) print(i, ...))
+  prefix <- ""
+  nm <- names(x)
+  for (i in seq_along(x)) {
+    cat(prefix)
+    cat(nm[i], ":\n\n", sep = "")
+    print(x[[i]])
+    prefix <- "\n"
+  }
   invisible(x)
 }
 
@@ -288,7 +354,14 @@ print.group_tna <- function(x, ...) {
 print.group_tna_bootstrap <- function(x, ...) {
   check_missing(x)
   check_class(x, "group_tna_bootstrap")
-  lapply(x, \(i) print(i, ...))
+  prefix <- ""
+  nm <- names(x)
+  for (i in seq_along(x)) {
+    cat(prefix)
+    cat(nm[i], ":\n\n", sep = "")
+    print(x[[i]])
+    prefix <- "\n"
+  }
   invisible(x)
 }
 
@@ -306,10 +379,13 @@ print.group_tna_bootstrap <- function(x, ...) {
 print.summary.group_tna <- function(x, ...) {
   check_missing(x)
   check_class(x, "summary.group_tna")
-  if (inherits(x, "data.frame")) {
-    NextMethod(generic = "print", object = x, ...)
-  } else {
-    lapply(x, \(i) print(x = i, ...))
+  prefix <- ""
+  nm <- names(x)
+  for (i in seq_along(x)) {
+    cat(prefix)
+    cat(nm[i], ":\n\n", sep = "")
+    print(x[[i]])
+    prefix <- "\n"
   }
   invisible(x)
 }
@@ -364,14 +440,14 @@ print.group_tna_centralities <- function(x, ...) {
 print.group_tna_communities <- function(x, ...) {
   check_missing(x)
   check_class(x, "group_tna_communities")
-  Map(
-    function(y, i) {
-      print(i)
-      print(y, ...)
-    },
-    x,
-    names(x)
-  )
+  prefix <- ""
+  nm <- names(x)
+  for (i in seq_along(x)) {
+    cat(prefix)
+    cat(nm[i], ":\n\n", sep = "")
+    print(x[[i]])
+    prefix <- "\n"
+  }
   invisible(x)
 }
 
@@ -390,14 +466,14 @@ print.group_tna_communities <- function(x, ...) {
 print.group_tna_cliques <- function(x, ...) {
   check_missing(x)
   check_class(x, "group_tna_cliques")
-  Map(
-    function(y, i) {
-      print(i)
-      print(y, ...)
-    },
-    x,
-    names(x)
-  )
+  prefix <- ""
+  nm <- names(x)
+  for (i in seq_along(x)) {
+    cat(prefix)
+    cat(nm[i], ":\n\n", sep = "")
+    print(x[[i]])
+    prefix <- "\n"
+  }
   invisible(x)
 }
 
@@ -421,13 +497,13 @@ print.group_tna_cliques <- function(x, ...) {
 print.group_tna_stability <- function(x, ...) {
   check_missing(x)
   check_class(x, "group_tna_stability")
-  Map(
-    function(y, i) {
-      cat(i, ":\n\n", sep = "")
-      print(y, ...)
-    },
-    x,
-    names(x)
-  )
+  prefix <- ""
+  nm <- names(x)
+  for (i in seq_along(x)) {
+    cat(prefix)
+    cat(nm[i], ":\n\n", sep = "")
+    print(x[[i]])
+    prefix <- "\n"
+  }
   invisible(x)
 }
